@@ -2,6 +2,7 @@
 """
 from typing import List
 import logging
+import re
 
 try:
     from fastapi import FastAPI, Request, HTTPException
@@ -18,6 +19,7 @@ def add_auth_middleware(
     env: str,
     jwks_url: str = None,
     excludes: List[str] = None,
+    excludes_regex: List[str] = None,
 ):
     if not jwks_url:  # pragma: no coverage
         jwks_url = defaults.JWKS_URL
@@ -26,8 +28,12 @@ def add_auth_middleware(
     async def validate_jwt(request: Request, call_next):
         try:
             paths = [] if excludes is None else excludes
+            regex_paths = [] if excludes_regex is None else excludes_regex
             if request.url.path in paths:
                 return await call_next(request)
+            for regex_path in regex_paths:
+                if re.match(regex_path, request.url.path):
+                    return await call_next(request)
             jwt_token = request.headers.get('Authorization')
             if not jwt_token:
                 return JSONResponse(status_code=401, content={'error': 'Missing JWT token'})
